namespace java com.example.myapp.entry
namespace php MyApp.Entry
namespace js MyApp.Entry

include "myapp.user.thrift"

/** エントリの種別 */
enum EntryType {
  /** 文字だけのエントリ */
  TEXT = 1,
  /** 写真付きエントリ */
  PHOTO = 2,
}

/** エントリ情報 */
struct Entry {
  1: required i64 id,
  2: optional myapp.user.User owner,
  3: required EntryType entryType,
  /** エントリのテキスト */
  4: required string text,
  /** エントリの画像。EntryTypeがTEXTのときはnull */
  5: optional string photoUrl,
}

/** 定数で定義されていない言語を指定された時の例外 */
exception InvalidLanguageException {}

service EntryService
{
  /** 投稿ユーザの言語をもとにエントリ一覧を取得 */
  list<Entry> findByUserLanguage(
    1: string language, 2: i64 page, 3: i64 perPage,
  ) throws (
    /** リクエストされた言語が未定義だったら例外 */
    1: InvalidLanguageException ex
  ),
}
